==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ACmpeqBinop.h <==
// public final class soot.jimple.parser.node.ACmpeqBinop

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 14f2c27f016eb129 soot_jimple_parser_node_ACmpeqBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_ACmpeqBinop_H_
#define _JC_soot_jimple_parser_node_ACmpeqBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TCmpeq$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ACmpeqBinop$sub_refs	_jc_soot_jimple_parser_node_ACmpeqBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ACmpeqBinop$sub_nonrefs	_jc_soot_jimple_parser_node_ACmpeqBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpeqBinop$refs	_jc_soot_jimple_parser_node_ACmpeqBinop$refs;
typedef struct _jc_soot_jimple_parser_node_ACmpeqBinop$nonrefs	_jc_soot_jimple_parser_node_ACmpeqBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpeqBinop$object	_jc_soot_jimple_parser_node_ACmpeqBinop$object;

typedef const struct _jc_soot_jimple_parser_node_ACmpeqBinop$vmethods	_jc_soot_jimple_parser_node_ACmpeqBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ACmpeqBinop$vtable	_jc_soot_jimple_parser_node_ACmpeqBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_ACmpeqBinop$vtype	_jc_soot_jimple_parser_node_ACmpeqBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ACmpeqBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *);
extern void _jc_soot_jimple_parser_node_ACmpeqBinop$method$_init$b45b30c5e11b9ece(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *, struct _jc_soot_jimple_parser_node_TCmpeq$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ACmpeqBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ACmpeqBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *);
extern struct _jc_soot_jimple_parser_node_TCmpeq$object *_jc_soot_jimple_parser_node_ACmpeqBinop$method$getCmpeq$0b8c24bc40cc82e4(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *);
extern void _jc_soot_jimple_parser_node_ACmpeqBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ACmpeqBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ACmpeqBinop$method$setCmpeq$dd28e9538c5b7656(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *, struct _jc_soot_jimple_parser_node_TCmpeq$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ACmpeqBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ACmpeqBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ACmpeqBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ACmpeqBinop$method_info$getCmpeq$0b8c24bc40cc82e4;
extern _jc_method _jc_soot_jimple_parser_node_ACmpeqBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ACmpeqBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ACmpeqBinop$method_info$setCmpeq$dd28e9538c5b7656;
extern _jc_method _jc_soot_jimple_parser_node_ACmpeqBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ACmpeqBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *);
	struct _jc_soot_jimple_parser_node_TCmpeq$object	*(*getCmpeq$0b8c24bc40cc82e4)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setCmpeq$dd28e9538c5b7656)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *, struct _jc_soot_jimple_parser_node_TCmpeq$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ACmpeqBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_ACmpeqBinop$vmethods	soot_jimple_parser_node_ACmpeqBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_ACmpeqBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ACmpeqBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpeqBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TCmpeq$object	*__5fcmpeq__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpeqBinop$refs {
    _jc_soot_jimple_parser_node_ACmpeqBinop$sub_refs	soot_jimple_parser_node_ACmpeqBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpeqBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpeqBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_ACmpeqBinop$sub_nonrefs	soot_jimple_parser_node_ACmpeqBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ACmpeqBinop$object {
	_jc_soot_jimple_parser_node_ACmpeqBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ACmpeqBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_ACmpeqBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ACmpeqBinop$vtype _jc_soot_jimple_parser_node_ACmpeqBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ACmpeqBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ACmpeqBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_ACmpeqBinop_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ACmpeqBinop.h <==
// public final class soot.jimple.parser.node.ACmpeqBinop

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 14f2c27f016eb129 soot_jimple_parser_node_ACmpeqBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_ACmpeqBinop_H_
#define _JC_soot_jimple_parser_node_ACmpeqBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TCmpeq$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ACmpeqBinop$sub_refs	_jc_soot_jimple_parser_node_ACmpeqBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ACmpeqBinop$sub_nonrefs	_jc_soot_jimple_parser_node_ACmpeqBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpeqBinop$refs	_jc_soot_jimple_parser_node_ACmpeqBinop$refs;
typedef struct _jc_soot_jimple_parser_node_ACmpeqBinop$nonrefs	_jc_soot_jimple_parser_node_ACmpeqBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpeqBinop$object	_jc_soot_jimple_parser_node_ACmpeqBinop$object;

typedef const struct _jc_soot_jimple_parser_node_ACmpeqBinop$vmethods	_jc_soot_jimple_parser_node_ACmpeqBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ACmpeqBinop$vtable	_jc_soot_jimple_parser_node_ACmpeqBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_ACmpeqBinop$vtype	_jc_soot_jimple_parser_node_ACmpeqBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ACmpeqBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpeqBinop$method$_init$b45b30c5e11b9ece(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *, struct _jc_soot_jimple_parser_node_TCmpeq$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ACmpeqBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ACmpeqBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TCmpeq$object *_jc_soot_jimple_parser_node_ACmpeqBinop$method$getCmpeq$0b8c24bc40cc82e4(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpeqBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpeqBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpeqBinop$method$setCmpeq$dd28e9538c5b7656(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *, struct _jc_soot_jimple_parser_node_TCmpeq$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ACmpeqBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ACmpeqBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ACmpeqBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ACmpeqBinop$method_info$getCmpeq$0b8c24bc40cc82e4;
extern _jc_method _jc_soot_jimple_parser_node_ACmpeqBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ACmpeqBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ACmpeqBinop$method_info$setCmpeq$dd28e9538c5b7656;
extern _jc_method _jc_soot_jimple_parser_node_ACmpeqBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ACmpeqBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TCmpeq$object	*(*getCmpeq$0b8c24bc40cc82e4)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setCmpeq$dd28e9538c5b7656)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *, struct _jc_soot_jimple_parser_node_TCmpeq$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpeqBinop$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ACmpeqBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_ACmpeqBinop$vmethods	soot_jimple_parser_node_ACmpeqBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_ACmpeqBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ACmpeqBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpeqBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TCmpeq$object	*__5fcmpeq__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpeqBinop$refs {
    _jc_soot_jimple_parser_node_ACmpeqBinop$sub_refs	soot_jimple_parser_node_ACmpeqBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpeqBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpeqBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_ACmpeqBinop$sub_nonrefs	soot_jimple_parser_node_ACmpeqBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ACmpeqBinop$object {
	_jc_soot_jimple_parser_node_ACmpeqBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ACmpeqBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_ACmpeqBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ACmpeqBinop$vtype _jc_soot_jimple_parser_node_ACmpeqBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ACmpeqBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ACmpeqBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_ACmpeqBinop_H_ */
